==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.bc = function () {
        return new MassIndexIndicator();
    };
    MassIndexIndicator.prototype.get_y0 = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_zd = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };

==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.bb = function () {
        return new MassIndexIndicator();
    };
    MassIndexIndicator.prototype.get_aaa = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "aaa", {
        get: function () {
            return this.get_aaa();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_aan = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };
